@@ -14,6 +14,8 @@
 ( cd opt/kde/share/doc/HTML/sk/karm ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kate ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/kdat ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/kdat ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kdvi ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kdvi ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kmix ; rm -rf common )
@@ -54,6 +56,8 @@
 ( cd opt/kde/share/doc/HTML/sk/kcalc ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kdesu ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kdesu ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/kcron ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/kcron ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kedit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kfind ; rm -rf common )
@@ -66,22 +70,28 @@
 ( cd opt/kde/share/doc/HTML/sk/kooka ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/ksame ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/ksysv ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/ksysv ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ktron ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/ktron ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/kuser ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/kuser ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kview ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kview ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kwin4 ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kwin4 ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/lskat ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/lskat ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/kcoloredit ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/kcoloredit ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/klipper ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/klipper ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kompare ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/konsole ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/konsole ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/kpackage ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/kpackage ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/khelpcenter/faq ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/khelpcenter/faq ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/khelpcenter/quickstart ; rm -rf common )
@@ -104,6 +114,8 @@
 ( cd opt/kde/share/doc/HTML/sk/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kweather ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kweather ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/kwuftpd ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/kwuftpd ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kbugbuster ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kbugbuster ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kmenuedit ; rm -rf common )
@@ -114,6 +126,8 @@
 ( cd opt/kde/share/doc/HTML/sk/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kaddressbook ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/kaddressbook ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
+( cd opt/kde/share/doc/HTML/sk/kxconfig ; rm -rf common )
+( cd opt/kde/share/doc/HTML/sk/kxconfig ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/sk/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/sk/common ; rm -rf qpl-license.html )
@@ -340,8 +354,6 @@
 ( cd opt/kde/share/doc/HTML/sk/kspell ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/ktimer ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/ktimer ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
-( cd opt/kde/share/doc/HTML/sk/kwrite ; rm -rf common )
-( cd opt/kde/share/doc/HTML/sk/kwrite ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/megami ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/sk/megami ; ln -sf /opt/kde/share/doc/HTML/sk/common common )
 ( cd opt/kde/share/doc/HTML/sk/kreversi ; rm -rf common )
